bayespy.inference.vmp.nodes.constant.Constant.__init__
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. automethod:: Constant.__init__